@@ -26,16 +26,21 @@
 #include "model/kgpgitemnode.h"
 #include "transactions/kgpgchangepass.h"
 
-#include <KGlobal>
-#include <KLocale>
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KToolInvocation>
+
 #include <QApplication>
 #include <QCheckBox>
+#include <QDesktopServices>
+#include <QDialogButtonBox>
 #include <QFormLayout>
 #include <QHBoxLayout>
 #include <QImage>
+#include <QLocale>
 #include <QPixmap>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace KgpgCore;
 
@@ -94,7 +99,7 @@ void KgpgTrustLabel::change()
 }
 
 KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *parent)
-	: KDialog(parent),
+	: QDialog(parent),
 	keychange(new KGpgChangeKey(node, this)),
 	m_node(node),
 	m_model(model),
@@ -106,10 +111,20 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
 
     setupUi(this);
 
-    setButtons(Ok | Apply | Cancel);
-    setDefaultButton(Ok);
-    setModal(true);
-    enableButtonApply(false);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QWidget *mainWidget = new QWidget(this);
+    setLayout(mainLayout);
+    mainLayout->addWidget(mainWidget);
+    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Apply);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &KgpgKeyInfo::okButtonClicked);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &KgpgKeyInfo::applyButtonClicked);
+    connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &KgpgKeyInfo::cancelButtonClicked);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &KgpgKeyInfo::reject);
+    okButton->setDefault(true);
+    buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 
     m_email->setUnderline(false);
     m_trust = new KgpgTrustLabel(this);
@@ -123,15 +138,16 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
         m_password->hide();
     }
 
-    setMainWidget(page);
+    mainLayout->addWidget(page);
+    mainLayout->addWidget(buttonBox);
 
-    connect(m_owtrust, SIGNAL(activated(int)), this, SLOT(slotChangeTrust(int)));
-    connect(m_photoid, SIGNAL(activated(QString)), this, SLOT(slotLoadPhoto(QString)));
-    connect(m_email, SIGNAL(leftClickedUrl(QString)), this, SLOT(slotOpenUrl(QString)));
-    connect(keychange, SIGNAL(done(int)), SLOT(slotApplied(int)));
-    connect(m_disable, SIGNAL(toggled(bool)), this, SLOT(slotDisableKey(bool)));
-    connect(m_expirationbtn, SIGNAL(clicked()), this, SLOT(slotChangeDate()));
-    connect(m_password, SIGNAL(clicked()), this, SLOT(slotChangePass()));
+    connect(m_owtrust, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &KgpgKeyInfo::slotChangeTrust);
+    connect(m_photoid, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::activated), this, &KgpgKeyInfo::slotLoadPhoto);
+    connect(m_email, static_cast<void (KUrlLabel::*)(const QString &)>(&KUrlLabel::leftClickedUrl), this, &KgpgKeyInfo::slotOpenUrl);
+    connect(keychange, &KGpgChangeKey::done, this, &KgpgKeyInfo::slotApplied);
+    connect(m_disable, &QCheckBox::toggled, this, &KgpgKeyInfo::slotDisableKey);
+    connect(m_expirationbtn, &QPushButton::clicked, this, &KgpgKeyInfo::slotChangeDate);
+    connect(m_password, &QPushButton::clicked, this, &KgpgKeyInfo::slotChangePass);
 
     displayKey();
     adjustSize();
@@ -195,11 +211,11 @@ void KgpgKeyInfo::displayKey()
     m_id->setText(m_node->getId().right(16));
     m_algorithm->setText(Convert::toString(key->algorithm()) + QLatin1String( " / " ) + Convert::toString(key->encryptionAlgorithm()));
     m_algorithm->setWhatsThis(i18n("<qt>The left part is the algorithm used by the <b>signature</b> key. The right part is the algorithm used by the <b>encryption</b> key.</qt>"));
-    m_creation->setText(KGlobal::locale()->formatDate(m_node->getCreation().date(), KLocale::ShortDate));
+    m_creation->setText(QLocale().toString(m_node->getCreation().date(), QLocale::ShortFormat));
     if (m_node->getExpiration().isNull())
         m_expiration->setText(i18nc("Unlimited key lifetime", "Unlimited"));
     else
-        m_expiration->setText(KGlobal::locale()->formatDate(m_node->getExpiration().date(), KLocale::ShortDate));
+        m_expiration->setText(QLocale().toString(m_node->getExpiration().date(), QLocale::ShortFormat));
     m_trust->setText(trust);
     m_trust->setColor(trustcolor);
     m_length->setText(m_node->getSize());
@@ -237,14 +253,14 @@ void KgpgKeyInfo::displayKey()
     if (!key->valid())
         m_disable->setChecked(true);
 
-    connect(m_node, SIGNAL(expanded()), SLOT(slotKeyExpanded()));
+    connect(m_node, &KGpgKeyNode::expanded, this, &KgpgKeyInfo::slotKeyExpanded);
     m_node->expand();
     m_photoid->clear();
 }
 
 void KgpgKeyInfo::slotOpenUrl(const QString &url) const
 {
-    KToolInvocation::invokeBrowser(url);
+    QDesktopServices::openUrl(QUrl(url));
 }
 
 void KgpgKeyInfo::slotLoadPhoto(const QString &uid)
@@ -261,7 +277,7 @@ void KgpgKeyInfo::slotChangeDate()
 	QPointer<SelectExpiryDate> dialog = new SelectExpiryDate(this, m_node->getExpiration());
 	if (dialog->exec() == QDialog::Accepted) {
 		keychange->setExpiration(dialog->date());
-		enableButtonApply(keychange->wasChanged());
+		buttonBox->button(QDialogButtonBox::Apply)->setEnabled(keychange->wasChanged());
 	}
 	delete dialog;
 }
@@ -269,14 +285,14 @@ void KgpgKeyInfo::slotChangeDate()
 void KgpgKeyInfo::slotDisableKey(const bool ison)
 {
 	keychange->setDisable(ison);
-	enableButtonApply(keychange->wasChanged());
+	buttonBox->button(QDialogButtonBox::Apply)->setEnabled(keychange->wasChanged());
 }
 
 void KgpgKeyInfo::slotChangePass()
 {
 	KGpgChangePass *cp = new KGpgChangePass(this, m_node->getId());
 
-	connect(cp, SIGNAL(done(int)), SLOT(slotInfoPasswordChanged(int)));
+	connect(cp, &KGpgChangePass::done, this, &KgpgKeyInfo::slotInfoPasswordChanged);
 
 	cp->start();
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
@@ -305,14 +321,14 @@ void KgpgKeyInfo::slotInfoPasswordChanged(int result)
 void KgpgKeyInfo::slotChangeTrust(const int newtrust)
 {
 	keychange->setOwTrust(static_cast<gpgme_validity_t>(newtrust + 1));
-	enableButtonApply(keychange->wasChanged());
+	buttonBox->button(QDialogButtonBox::Apply)->setEnabled(keychange->wasChanged());
 }
 
 void KgpgKeyInfo::setControlEnable(const bool b)
 {
     m_owtrust->setEnabled(b);
     m_disable->setEnabled(b);
-    enableButtonApply(b && keychange->wasChanged());
+    buttonBox->button(QDialogButtonBox::Apply)->setEnabled(b && keychange->wasChanged());
 
     if (m_expirationbtn)
         m_expirationbtn->setEnabled(b);
@@ -325,24 +341,23 @@ void KgpgKeyInfo::setControlEnable(const bool b)
         QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 }
 
-void KgpgKeyInfo::slotButtonClicked(int button)
+void KgpgKeyInfo::okButtonClicked()
 {
-	switch (button) {
-	case Ok:
-		m_closewhendone = true;
-		// Fall-through
-	case Apply:
-		setControlEnable(false);
-		keychange->apply();
-		break;
-	case Cancel:
-		if (m_keywaschanged && m_node)
-			emit keyNeedsRefresh(m_node);
-		reject();
-		break;
-	default:
-		KDialog::slotButtonClicked(button);
-	}
+	m_closewhendone = true;
+	applyButtonClicked();
+}
+
+void KgpgKeyInfo::applyButtonClicked()
+{
+	setControlEnable(false);
+	keychange->apply();
+}
+
+void KgpgKeyInfo::cancelButtonClicked()
+{
+	if (m_keywaschanged && m_node)
+		emit keyNeedsRefresh(m_node);
+	reject();
 }
 
 void KgpgKeyInfo::slotApplied(int result)
